
/*******************************************************************************

 Copyright (c) 2009, Charles McGarvey
 All rights reserved.
 
 Redistribution   and   use  in  source  and  binary  forms,  with  or  without
 modification, are permitted provided that the following conditions are met:
 
   * Redistributions  of  source  code  must retain the above copyright notice,
     this list of conditions and the following disclaimer.
   * Redistributions  in binary form must reproduce the above copyright notice,
     this  list of conditions and the following disclaimer in the documentation
     and/or other materials provided with the distribution.
 
 THIS  SOFTWARE  IS  PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND  ANY  EXPRESS  OR  IMPLIED  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN  NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 FOR  ANY  DIRECT,  INDIRECT,  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 DAMAGES  (INCLUDING,  BUT  NOT  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 SERVICES;  LOSS  OF  USE,  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 CAUSED  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR  TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*******************************************************************************/

#ifndef _HUD_HH_
#define _HUD_HH_

/**
 * @file Hud.hh
 * Heads-up Display
 */

#include <Moof/Drawable.hh>
#include <Moof/Layer.hh>
#include <Moof/Math.hh>
#include <Moof/Rectangle.hh>

#include "Tilemap.hh"


// TODO this stuff is still just hacked up

class ProgressBar : public Mf::Drawable
{
public:

	ProgressBar(const Tilemap& tilemap, Tilemap::Index index);

	void resize(const Mf::Rectangle& rect);

	void setProgress(Mf::Scalar progress);

	void draw(Mf::Scalar alpha = 0.0) const;

private:

	Mf::Scalar	mProgress;

	Mf::Vector2	mVertices[8];
	Mf::Scalar	mWidth;

	Tilemap		mTilemap;
	Mf::Scalar	mTexCoords[8];
	Mf::Scalar	mMidCoords[2];
};


class Hud;
typedef boost::shared_ptr<Hud> HudP;

class Hud : public Mf::Layer
{
public:

	Hud();

	static HudP alloc()
	{
		return HudP(new Hud);
	}

	void setBar1Progress(Mf::Scalar progress)
	{
		// pass through
		mBar1.setProgress(progress);
	}

	void setBar2Progress(Mf::Scalar progress)
	{
		// pass through
		mBar2.setProgress(progress);
	}

	void setNumber(unsigned value);

	void resize(int width, int height);

	void draw(Mf::Scalar alpha = 0.0) const;
	bool handleEvent(Mf::Event& event);

private:

	ProgressBar	mBar1;
	ProgressBar	mBar2;

	unsigned	mNumber;
	Tilemap		mFont;

	Mf::Matrix4	mProjection;
};


#endif // _HUD_HH_

/** vim: set ts=4 sw=4 tw=80: *************************************************/

